@@ -2,7 +2,7 @@ use std::collections::VecDeque;
 
 use crate::{Event, Moment, Sheet};
 
-#[derive(Eq, PartialEq, Copy, Clone)]
+#[derive(Eq, PartialEq, Copy, Clone, Debug)]
 struct TimeSignature {
 	// Beats per bar.
 	numerator: u8,
@@ -19,6 +19,7 @@ impl TimeSignature {
 }
 
 /// An iterator over bars in a MIDI [Sheet].
+#[derive(Debug, Clone, PartialEq)]
 pub struct Bars {
 	time_sig: TimeSignature,
 	// beat_32s: u8,
@@ -30,11 +31,8 @@ impl Iterator for Bars {
 	type Item = Vec<Moment>;
 
 	fn next(&mut self) -> Option<Self::Item> {
-		if self.buf.is_empty() {
-			return None;
-		}
-		// Check if start of bar has time signature.
-		let first = self.buf.pop_front().unwrap();
+		// Check if start of the bar has time signature.
+		let first = self.buf.pop_front()?;
 		if let Some(time_sig) = find_time_sig(&first) {
 			self.time_sig = time_sig;
 		}
@@ -42,7 +40,7 @@ impl Iterator for Bars {
 			return Some(vec![first]);
 		}
 
-		let len_32nd = self.tpb / 8.0; // self.beat_32s as f32;
+		let len_32nd = self.tpb / 8.0;
 		let chunk_len = (self.time_sig.bar_32s() * len_32nd as f32) as usize;
 		let mut temp = Vec::with_capacity(chunk_len);
 		temp.push(first);
